@@ -13,7 +13,7 @@ use Mozilla::CA;
 
 use vars qw[ $VERSION ];
 
-$VERSION = '0.35';
+$VERSION = '0.36';
 
 BEGIN {
   Finance::Bank::Postbank_de->mk_accessors(qw( agent login password urls ));
@@ -100,7 +100,7 @@ sub get_login_page {
   $self->agent->ssl_opts( SSL_ca_file => Mozilla::CA::SSL_ca_file() );
 
   my $agent = $self->agent();
-  $agent->add_header("If-SSL-Cert-Subject" => qr{\Q/1.3.6.1.4.1.311.60.2.1.3=DE/1.3.6.1.4.1.311.60.2.1.1=Bonn/businessCategory=Private Organization/serialNumber=HRB6793/C=DE/postalCode=53113/ST=NRW/L=Bonn/street=Friedrich Ebert Allee 114 126/O=Deutsche Postbank AG/OU=PB Systems AG/CN=banking.postbank.de}); 
+  $agent->add_header("If-SSL-Cert-Subject" => qr{\Q/1.3.6.1.4.1.311.60.2.1.3=DE/1.3.6.1.4.1.311.60.2.1.1=Bonn/businessCategory=Private Organization/serialNumber=HRB6793/C=DE/postalCode=53113/ST=Nordrhein-Westfalen/L=Bonn/street=Friedrich Ebert Allee 114 126/O=Deutsche Postbank AG/OU=Postbank Systems AG/CN=banking.postbank.de}); 
 
   $agent->get(LOGIN);
   $self->log_httpresult();
